from rest_framework import generics
from rest_framework.decorators import permission_classes, api_view
from rest_framework.permissions import IsAuthenticated
from clusterCore.models import c123_node
from .serializer import c123_CreatePostgresPodSerializer
from clusterCore.api.serializer import get_create_node_response
from ...enums import DBType
from ...exceptions import APIException410
from c123_kubernetes.tasks import drop_k8s_pg_pod
from ...tasks import append_status_cmd


class c123_CreatePostgresPodView(generics.CreateAPIView):
    permission_classes = [IsAuthenticated]
    queryset = c123_node.objects.all()
    serializer_class = c123_CreatePostgresPodSerializer

    def create(self, request, *args, **kwargs):
        return get_create_node_response(self, request, *args, **kwargs)


@api_view(['POST'])
@permission_classes((IsAuthenticated,))
def DropK8SPgNode(request):
    node_id = request.data.get("node_id")
    api_call = request.data.get("rest_api")
    final_backup = request.data.get('final_backup')
    if api_call:
        node = c123_node.objects.filter(name=node_id, type=DBType.POSTGRES_K8S.value, ind_deleted=False).first()
    else:
        node = c123_node.objects.filter(pk=node_id, type=DBType.POSTGRES_K8S.value, ind_deleted=False).first()

    if not node:
        raise APIException410("node id {} not available".format(node_id))

    task = drop_k8s_pg_pod(node, final_backup)

    return append_status_cmd(request, task)
